from sqlalchemy import Column, String, Integer, Float, ForeignKey, Text, Boolean
from sqlalchemy.orm import relationship
from app.models.base import BaseModel

class Item(BaseModel):
    """Model for inventory items."""
    sku = Column(String, unique=True, index=True, nullable=False)
    name = Column(String, index=True, nullable=False)
    description = Column(Text, nullable=True)
    quantity = Column(Integer, default=0, nullable=False)
    reorder_level = Column(Integer, default=5, nullable=False)
    unit_price = Column(Float, nullable=False)
    category_id = Column(Integer, ForeignKey('categorys.id'), nullable=True)
    supplier_id = Column(Integer, ForeignKey('suppliers.id'), nullable=True)
    location = Column(String, nullable=True)
    is_active = Column(Boolean, default=True)
    
    # Relationships
    category = relationship("Category", back_populates="items")
    supplier = relationship("Supplier", back_populates="items")
    transaction_items = relationship("TransactionItem", back_populates="item")
    
class TransactionType:
    PURCHASE = "purchase"
    SALE = "sale"
    ADJUSTMENT = "adjustment"
    RETURN = "return"
    TRANSFER = "transfer"

class Transaction(BaseModel):
    """Model for inventory transactions (purchases, sales, adjustments, etc.)."""
    transaction_type = Column(String, nullable=False)
    reference_number = Column(String, nullable=True)
    notes = Column(Text, nullable=True)
    
    # Relationships
    items = relationship("TransactionItem", back_populates="transaction")

class TransactionItem(BaseModel):
    """Model for items involved in a transaction."""
    transaction_id = Column(Integer, ForeignKey('transactions.id'), nullable=False)
    item_id = Column(Integer, ForeignKey('items.id'), nullable=False)
    quantity = Column(Integer, nullable=False)
    unit_price = Column(Float, nullable=False)
    
    # Relationships
    transaction = relationship("Transaction", back_populates="items")
    item = relationship("Item", back_populates="transaction_items")